transport_script_ref

Function transport_script_ref 

pub fn transport_script_ref(err: &EngineError) -> Option<&ScriptError>
If err is a Transport carrying a ScriptError, return a reference to the inner script error. Returns None for other variants and for Transport whose inner source is not a ScriptError (e.g. a Postgres-backed transport error).